# ROCKPAPERSTEROIDS PACKAGE

This package contains everything necessary for an extended version of the rock paper scissors game

#files 

python_code - contains all working code

#installation 
pip install ROCKPAPERSTEROIDS

# TO PLAY 
from ROCKPAPERSTEROIDS IMPORT play